@@ -54,120 +54,67 @@ def predictor(input_dir=None,
               input_model=None,
               output_dir=None,
               output_probabilities=False,
-              detection_threshold=0.55,                
-              P_threshold=0.35,
-              S_threshold=0.35, 
+              detection_threshold=0.3,                
+              P_threshold=0.1,
+              S_threshold=0.1, 
               number_of_plots=10,
               plot_mode='time',
               estimate_uncertainty=False, 
               number_of_sampling=5,
-              loss_weights=[0.05, 0.40, 0.55],
+              loss_weights=[0.03, 0.40, 0.58],
               loss_types=['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy'],
               input_dimention=(6000, 3),
               normalization_mode='std',
-              batch_size=200,
+              batch_size=500,
               gpuid=None,
               gpu_limit=None,
               number_of_cpus=5,
               use_multiprocessing=True,
               keepPS=True,
               spLimit=60): 
- 
-    """
-    Applies a trained model to a windowed waveforms to perform both detection and picking at the same time. 
+    
+    r"""
+    
+    Applies a trained model to a windowed waveform to perform both detection and picking at the same time. 
 
-    Parameters
-    ----------
-       input_dir: str, (default = None)
-           Directory name containing hdf5 and csv files-preprocessed data.
-           
-       input_hdf5: str, (default = None)
-           Path to a hdf5 file containing only one class of "data" with numpy arries containing 3 component waveforms each 1 min long.
-           
-       input_csv: str, (default = None)
-           Path to a csv file with one column (trace_name) listing the name of all datasets in the hdf5 file.
-           
-       input_model: str, (default = None)
-           Path to a trained model.
-           
-       output_dir: str, (default = None)
-           Output directory.
-           
-       output_probabilities: bool, (default = False)
-           If True, it will output probabilities and estimated uncertainties for each trace into a hdf file.
-           
-       detection_threshold: float, (default = 0.20)
-           A value which the detection probabilities above it will be considered as an event.  
-           
-       P_threshold: float, (default = 0.10)
-           A value which the P probabilities above it will be considered as P arrival.
-           
-       S_threshold: float, (default = 0.10)
-           A value which the S probabilities above it will be considered as S arrival. 
-           
-       number_of_plots: {positive integer, None}, (default = 10)
-           Number of output plots.     
+    Args:        
+        input_dir (str, optional): Directory name containing hdf5 and csv files-preprocessed data. Defaults to None. 
+        input_hdf5 (str, optional): Path to an hdf5 file containing only one class of "data" with NumPy arrays containing 3 component waveforms each 1 min long. Defaults to None.          
+        input_csv (str, optional): Path to a CSV file with one column (trace_name) listing the name of all datasets in the hdf5 file. Defaults to None.                  
+        input_model (str, optional): Path to a trained model. Defaults to None.           
+        output_dir (str, optional): Output directory. Defaults to None.   
+        output_probabilities (bool, optional): If True, it will output probabilities and estimated uncertainties for each trace into an HDF file. Defaults to False.              
+        detection_threshold (float, optional): A value in which the detection probabilities above it will be considered as an event. Defaults to 0.3.                
+        P_threshold (float, optional): A value which the P probabilities above it will be considered as P arrival. Defaults to 0.1.            
+        S_threshold (float, optional): A value which the S probabilities above it will be considered as S arrival. Defaults to 0.1.               
+        number_of_plots (int, optional): The number of plots for detected events outputed for each station data. Defaults to 10.        
+        plot_mode (str, optional): The type of plots: 'time': only time series or 'time_frequency': time and spectrograms. Defaults to 'time'.             
+        estimate_uncertainty (bool, optional): If True uncertainties in the output probabilities will be estimated. Defaults to False.             
+        number_of_sampling (int, optional): The number of Monte Carlo sampling to estimate the uncertainties. Defaults to 5.             
+        loss_weights (list, [optional): Loss weights for detection, P picking, and S picking respectively. Defaults to [0.03, 0.40, 0.58].               
+        loss_types (list, optional): Loss types for detection, P picking, and S picking respectively. Defaults to ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy']        
+        input_dimention (int, optional): Loss types for detection, P picking, and S picking respectively. Defaults to (6000, 3).        
+        normalization_mode (str, optional): Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std': standard deviation. Defaults to 'std'           
+        batch_size: (int, optional): Batch size. Defaults to 500.           
+        gpuid (int, optional): Id of GPU used for the prediction. If using CPU set to None. Defaults to None.           
+        gpu_limit (tuple, optional): Set the maximum percentage of memory usage for the GPU. Defaults to None.
+        number_of_cpus (int, optional): Number of CPUs used for the parallel preprocessing and feeding of data for prediction. Defaults to 5.
+        use_multiprocessing (bool, optional): If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction. Defaults to True.
+        keepPS (bool, optional): If True, only detected events that have both P and S picks will be written otherwise those events with either P or S pick. Defaults to False.
+        spLimit (int, optional): S - P time in seconds. It will limit the results to those detections with events that have a specific S-P time limit. Defaults to 60.
 
-       plot_mode: string, (default = 'time')
-           Plot types, 'time': only time series, 'time_frequency': time and spectrograms. 
-           
-       estimate_uncertainty: bool, (default = False)
-           If True uncertainties in the output probabilities will be estimated. 
-           
-       number_of_sampling: positive integer, (default = 5)
-           Number of Monte Carlo sampling to estimate the uncertainties. 
-           
-       loss_weights: list of three floats, (default = [0.05, 0.40, 0.55])
-           Loss wieghts for detection, P picking, and S picking respectively.  
-           
-       loss_types: list of three str, (default = ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy'])
-           Loss types for detection, P picking, and S picking respectively.
-           
-       input_dimention: tuple, (default = (6000, 3)) 
-           Dimension of input traces. 
-           
-       normalization_mode: str, (default = 'std') 
-           Mode of normalization for data preprocessing, 'max': maximum amplitude among three componenet, 'std': standard deviation.
-           
-       batch_size: positive integer, (default = 200) 
-           Batch size.            
-           
-       gpuid: {positive integer, None}, (default = None) 
-           Id of GPU used for the prediction. If using CPU set to None. 
-           
-       gpu_limit: {positive integer, None}, (default = None) 
-           Set the maximum precentage of memomry usage for the GPU. 
-           
-       number_of_cpus: positive integer, (default = 5) 
-           Number of CPUs used for the parrallel preprocessing and feeding of data for prediction.   
-           
-       use_multiprocessing: bool, (default = True) 
-           If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction.
-           
-       keepPS: bool, (default = True) 
-           If True, only detected events that have both P and S picks will be written otherwise those events with either P or S pick. 
-           
-       spLimit : int, default : 60
-           S - P time in seconds. It will limit the results to those detections with events that have specific S-P time limit.
-           
-    rubric:: Notes
-        Estimating the uncertainties requiers multiple predictions and will increase the computational time. 
 
-    Generates
-    -------
-    ./output_dir/X_prediction_results.csv
-        A table containing all the detection, and picking results. Douplicated events are already removed.
+    Returns:
+        ./output_dir/STATION_OUTPUT/X_prediction_results.csv: A table containing all the detection, and picking results. Duplicated events are already removed.      
+        ./output_dir/STATION_OUTPUT/X_report.txt: A summary of the parameters used for prediction and performance.
+        ./output_dir/STATION_OUTPUT/figures: A folder containing plots detected events and picked arrival times. 
+        ./output_dir/STATION_OUTPUT/output_probabilities.hdf5: An hdf5 containing the predicted probabilities for all samples. 
+
+    Notes:
+        Estimating the uncertainties requires multiple predictions and will increase the computational time. 
         
-    ./output_dir/X_report.txt
-        A summary of parameters used for the prediction and perfomance.
-        
-    ./output_dir/figures 
-        A folder containing plots. 
-
-    ./output_dir/output_probabilities.hdf5 
-        An hdf5 containing the predicted probabilities for all samples.  
-               
-    """         
+    """ 
+   
     
     args = {
     "input_dir": input_dir,
@@ -376,22 +323,26 @@ def predictor(input_dir=None,
             
 def _gen_predictor(new_list, args, model): 
     
+    
     """ 
-    Peforms the predictions for the current batch.
+    
+    Performs the predictions for the current batch.
 
     Parameters
     ----------
-    new_list : list of str
+    new_list: list of str
         A list of trace names in the batch.
-    args : object
-        A argparse object containing all of the input parameters. 
+    args: dic
+        A dictionary containing all of the input parameters. 
+
     model: 
-        Compiled model used for the prediction.
+        The compiled model used for the prediction.
 
     Returns
     -------
-    prob_dic : dic
-        A dictionary containing output probabilites and their estimated standard deviations.
+    prob_dic: dic
+        A dictionary containing output probabilities and their estimated standard deviations.
+        
     """    
     
     prob_dic = dict()            
@@ -454,42 +405,54 @@ def _gen_predictor(new_list, args, model):
 def _gen_writer(new_list, args, prob_dic, pred_set, HDF_PROB, predict_writer, save_figs, csvPr_gen, plt_n, detection_memory, keepPS, spLimit):
     
     """ 
-    Applies the detection and picking on the output predicted probabilities and if it founds any, write them out in the csv file,
+    
+    Applies the detection and picking on the output predicted probabilities and if it founds any, write them out in the CSV file,
     makes the plots, and save the probabilities and uncertainties.
 
     Parameters
     ----------
-    new_list : list of str
+    new_list: list of str
         A list of trace names in the batch.
-    args : object
-        A argparse object containing all of the input parameters. 
-    prob_dic : dic
-        A dictionary containing output probabilites and their estimated standard deviations.
-    pred_set : dic
-        A dictionary containing hdf datesets for the current batch. 
-    HDF_PROB : obj
-        For writing out the probabilites and uncertainties. 
-    predict_writer : obj
-        For writing out the detection/picking results in the csv file.        
-    save_figs : str
+
+    args: dic
+        A dictionary containing all of the input parameters. 
+
+    prob_dic: dic
+        A dictionary containing output probabilities and their estimated standard deviations.
+        
+    pred_set: dic
+        A dictionary containing HDF datasets for the current batch. 
+
+    HDF_PROB: obj
+        For writing out the probabilities and uncertainties. 
+
+    predict_writer: obj
+        For writing out the detection/picking results in the CSV file.    
+    
+    save_figs: str
         Path to the folder for saving the plots. 
+
     csvPr_gen : obj
-        For writing out the detection/picking results in the csv file.       
-    plt_n : positive integer
+        For writing out the detection/picking results in the CSV file.   
+    
+    plt_n: positive integer
         Keep the track of plotted figures.     
-    detection_memory : list
+
+    detection_memory: list
         Keep the track of detected events.  
-    spLimit : int, default : 60
-        S - P time in seconds. It will limit the results to those detections with events that have specific S-P time limit.
+
+    spLimit: int, default : 60
+        S - P time in seconds. It will limit the results to those detections with events that have a specific S-P time limit.
         
     Returns
     -------
-    plt_n : positive integer
+    plt_n: positive integer
         Keep the track of plotted figures. 
         
-    detection_memory : list
+    detection_memory: list
         Keep the track of detected events.  
         
+        
     """    
     
     for ts in range(prob_dic['DD_mean'].shape[0]): 
@@ -558,20 +521,26 @@ def _gen_writer(new_list, args, prob_dic, pred_set, HDF_PROB, predict_writer, sa
 def _output_writter_prediction(dataset, predict_writer, csvPr, matches, snr, detection_memory):
     
     """ 
-    Writes the detection & pcking resutls into a csv file.
+    
+    Writes the detection & picking results into a CSV file.
 
     Parameters
     ----------
-    dataset : hdf5 obj
-        Dateset object of the trece.
-    predict_writer : obj
-        For writing out the detection/picking results in the csv file.        
-    csvPr : obj
-        For writing out the detection/picking results in the csv file.  
-    matches : dic
-        Contains the information for the detected and picked event.    
-    snr : list of two floats
-        Estimated signal to noise ratios for picked P and S phases.       
+    dataset: hdf5 obj
+        Dataset object of the trace.
+
+    predict_writer: obj
+        For writing out the detection/picking results in the CSV file.
+        
+    csvPr: obj
+        For writing out the detection/picking results in the CSV file.  
+
+    matches: dic
+        It contains the information for the detected and picked event.   
+ 
+    snr: list of two floats
+        Estimated signal to noise ratios for picked P and S phases.      
+ 
     detection_memory : list
         Keep the track of detected events.          
         
@@ -580,6 +549,7 @@ def _output_writter_prediction(dataset, predict_writer, csvPr, matches, snr, det
     detection_memory : list
         Keep the track of detected events.  
         
+        
     """      
 
     trace_name = dataset.attrs["trace_name"]
@@ -682,32 +652,44 @@ def _output_writter_prediction(dataset, predict_writer, csvPr, matches, snr, det
 def _plotter_prediction(data, evi, args, save_figs, yh1, yh2, yh3, yh1_std, yh2_std, yh3_std, matches):
 
     """ 
-    Generates plots.
+    
+    Generates plots of detected events waveforms, output predictions, and picked arrival times.
 
     Parameters
     ----------
-    data : numpy array
+    data: NumPy array
         3 component raw waveform.
+
     evi : str
         Trace name.  
-    args : object
-        A argparse object containing all of the input parameters. 
-    save_figs : str
+
+    args: dic
+        A dictionary containing all of the input parameters. 
+
+    save_figs: str
         Path to the folder for saving the plots. 
-    yh1 : 1D array
+
+    yh1: 1D array
         Detection probabilities. 
-    yh2 : 1D array
-        P arrival probabilities.         
-    yh3 : 1D array
-        S arrival probabilities.  
-    yh1_std : 1D array
+
+    yh2: 1D array
+        P arrival probabilities.    
+     
+    yh3: 1D array
+        S arrival probabilities. 
+ 
+    yh1_std: 1D array
         Detection standard deviations. 
-    yh2_std : 1D array
-        P arrival standard deviations.         
-    yh3_std : 1D array
+
+    yh2_std: 1D array
+        P arrival standard deviations.  
+       
+    yh3_std: 1D array
         S arrival standard deviations. 
-    matches : dic
-        Contains the information for the detected and picked event.            
+
+    matches: dic
+        Contains the information for the detected and picked event.   
+         
         
     """  
 
@@ -1142,21 +1124,24 @@ def _plotter_prediction(data, evi, args, save_figs, yh1, yh2, yh3, yh1_std, yh2_
 def _get_snr(data, pat, window = 200):
     
     """ 
+    
     Estimates SNR.
     
     Parameters
     ----------
-    data : numpy array
+    data: NumPy array
         3 component data.     
-    pat : positive integer
+
+    pat: positive integer
         Sample point where a specific phase arrives.  
-    window : positive integer
-        The length of window for calculating the SNR (in sample).         
+
+    window: positive integer
+        The length of the window for calculating the SNR (in the sample).         
         
     Returns
     -------   
     snr : {float, None}
-       Estimated SNR in db.  
+       Estimated SNR in db.   
         
     """      
        
